Crate gorilla

Crate gorilla 

github crates.io docs.rs

An implementation of Gorilla compression for Rust.

This was my first ever Rust project. I’ve kept it mostly as-is, only following clippy and removing some instances of unsafe. Needless to say, you should probably not be using this.

Structs

Block
BlockBuilder
BlockIterator

Enums

BlockError